@@ -4,6 +4,9 @@
 #'
 #' @param lid ESPN League ID, defaulted because all return the same data.
 #' @param week The scoring period to return, defaults to [ffl_week()].
+#' @param limit The limit of players to return, `""` or `NULL` returns all.
+#'   Defaults to 50, which is the default limit used by ESPN. Removing the limit
+#'   can make the request take a long time.
 #' @return A tibble of players.
 #' @examples
 #' \dontrun{
@@ -13,10 +16,12 @@
 #' @importFrom jsonlite toJSON
 #' @importFrom httr GET add_headers accept_json content
 #' @export
-all_players <- function(lid = getOption("lid"), week = ffl_week()) {
+all_players <- function(lid = getOption("lid"), week = ffl_week(), limit = 50) {
   if (is.null(lid)) lid <- 252353
+  if (is.null(limit)) limit <- ""
   xff <- list(
     players = list(
+      limit = limit,
       sortPercOwned = list(
         sortAsc = FALSE,
         sortPriority = 1
@@ -84,6 +89,7 @@ all_players <- function(lid = getOption("lid"), week = ffl_week()) {
     }
   }
   out <- data.frame(
+    stringsAsFactors = FALSE,
     id = p$player$id,
     first = p$player$firstName,
     last = p$player$lastName,
